# import PyOfficeRobot
#
#
# class MainWeChat():
#     def send_message(self, who, message):  # 给指定人，发送消息
#         PyOfficeRobot.chat.send_message(who, message)
#
#     def send_file(self, who, file):  # 给指定人，发送文件
#         PyOfficeRobot.file.send_file(who, file)
