from office.api import word
from office.api import pdf
from office.api import image
from office.api import file
from office.api import video
from office.api import tools
from office.api import ppt
from office.api import excel
from office.api import wechat
# 以下是beta版本
from office.api.testApi import ruiming

print('=' * 30)
print('【python-office库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、全部功能【视频 & 文字】教程：https://www.python-office.com/')
print('2、请+【项目交流群】：http://t.cn/A6SSrID0')
print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/python-office')
print('=' * 30)
